'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var IntlMessageFormat = _interopDefault(require('intl-messageformat'));
var router = require('next/router');

var NextIntlContext = /*#__PURE__*/React.createContext(undefined);

function NextIntlProvider(_ref) {
  var children = _ref.children,
      locale = _ref.locale,
      messages = _ref.messages;
  return React__default.createElement(NextIntlContext.Provider, {
    value: {
      messages: messages,
      locale: locale
    }
  }, children);
}

function resolvePath(messages, idPath) {
  var message = messages;
  idPath.split('.').forEach(function (part) {
    var next = message[part];

    {
      if (!part || !next) {
        throw new Error("Could not resolve `" + idPath + "` in `" + JSON.stringify(messages, null, 2) + "`.");
      }
    }

    message = next;
  });
  return message;
}

function prepareTranslationValues(values) {
  if (!values) return values; // Workaround for https://github.com/formatjs/formatjs/issues/1467

  var transformedValues = {};
  Object.keys(values).forEach(function (key) {
    var value = values[key];
    var transformed;

    if (typeof value === 'function') {
      transformed = function transformed(children) {
        var result = value(children);
        return React.isValidElement(result) ? React.cloneElement(result, {
          key: result.key || key + String(children)
        }) : result;
      };
    } else {
      transformed = value;
    }

    transformedValues[key] = transformed;
  });
  return transformedValues;
}
/**
 * Translates messages from the given path by using the ICU syntax.
 * See https://formatjs.io/docs/core-concepts/icu-syntax.
 *
 * If no path is provided, all available messages are returned.
 *
 * The path can also indicate nesting by using a dot (e.g. `namespace.Component`).
 */


function useTranslations(path) {
  var context = React.useContext(NextIntlContext);
  var nextLocale = router.useRouter().locale;
  var cachedFormatsByLocaleRef = React.useRef({});

  if (!context) {
    {
      throw new Error('No NextIntlContext configured.');
    }
  }

  var locale = context.locale || nextLocale;
  var allMessages = context.messages;
  var messages = React.useMemo(function () {
    return path ? resolvePath(allMessages, path) : allMessages;
  }, [allMessages, path]);

  {
    if (!messages) {
      throw new Error("No messages for component `" + path + "` found.");
    }
  }

  function translate(
  /** Use a dot to indicate a level of nesting (e.g. `namespace.nestedLabel`). */
  idPath, values) {
    var _cachedFormatsByLocal;

    if (!locale) {
      {
        throw new Error('No `locale` received from `useRouter()`');
      }
    }

    var cachedFormatsByLocale = cachedFormatsByLocaleRef.current;
    var messageFormat;

    if ((_cachedFormatsByLocal = cachedFormatsByLocale[locale]) == null ? void 0 : _cachedFormatsByLocal[idPath]) {
      messageFormat = cachedFormatsByLocale[locale][idPath];
    } else {
      var message = resolvePath(messages, idPath);

      if (typeof message === 'object') {
        {
          throw new Error("Insufficient path specified for `" + idPath + "` in `" + path + "`.");
        }
      }

      messageFormat = new IntlMessageFormat(message, locale);

      if (!cachedFormatsByLocale[locale]) {
        cachedFormatsByLocale[locale] = {};
      }

      cachedFormatsByLocale[locale][idPath] = messageFormat;
    }

    var formattedMessage = messageFormat.format(prepareTranslationValues(values));

    {
      if (formattedMessage === undefined) {
        throw new Error("Unable to format " + path + "." + idPath);
      }
    }

    return formattedMessage;
  }

  return translate;
}

exports.NextIntlProvider = NextIntlProvider;
exports.useTranslations = useTranslations;
//# sourceMappingURL=next-intl.cjs.development.js.map
